Program StripLog_Remover;

{ Code Copyright 1997 (C) Lazor Software. Distributions of modified code
  without author's permission is prohibited. Just ask me and I'll more than
  likely let you do whatever you want with the code... except claim it as
  your own }

Uses Crt;

Const
  Ver = '2.0';

Var
  ActlogDAT,                                  { ACTIVITY log file var      }
  TemplogDAT    : Text;                       { temp ACTIVITY log file var }
  LinesRead,                                  { # lines read from log file }
  LinesWritten,                               { # lines written            }
  LinesStripped : Word;                       { # lines stripped           }
  ExitSave      : Pointer;                    { pointer to old exit proc   }
  ScanAgain,                                  { tells Not_Found proc if cmt
                                                already found              }
  Done          : Boolean;                    { completely done stripping? }

Procedure Usage;
Begin
  Writeln('Striplog REMOVER v',Ver);
  Writeln;
  Writeln('Usage:');
  Writeln;
  Writeln('    SLR [FULL path and file name of ACTIVITY.??? log]');
  Halt(1);
End;

{$F+}
Procedure DeInit;
Var
  ExitMsg : String;
Begin
  ExitProc := ExitSave;
  {$I-}
  Close(ActlogDAT);
  If IOResult <> 0 Then Write;   { clear IOResult flag }
  Close(TemplogDAT);
  If IOResult <> 0 Then Write;   { clear IOResult flag }
  Erase(TemplogDAT);
  If IOResult <> 0 Then Write;   { clear IOResult flag }
  {$I+}
  ExitMsg := '';
  If ErrorAddr <> Nil Then
    Case ExitCode of
      2   : ExitMsg := 'File not found';
      3   : ExitMsg := 'Path not found';
      4   : ExitMsg := 'Too many open files';
      5   : ExitMsg := 'Access denied';
      6   : ExitMsg := 'Invalid file handle';
      12  : ExitMsg := 'Invalid file access code';
      15  : ExitMsg := 'Invalid drive';
      16  : ExitMsg := 'Cannot remove current directory';
      17  : ExitMsg := 'Cannot rename across drives';
      100 : ExitMsg := 'Disk read error';
      101 : ExitMsg := 'Disk write error - Disk Full?';
      102 : ExitMsg := 'File not assigned';
      103 : ExitMsg := 'File not opened';
      104 : ExitMsg := 'File not open for input';
      105 : ExitMsg := 'File not open for output';
      106 : ExitMsg := 'Invalid numeric format';
      150 : ExitMsg := 'Disk is write protected';
      151 : ExitMsg := 'Unknown unit';
      152 : ExitMsg := 'Drive not ready';
      153 : ExitMsg := 'Unkown command';
      154 : ExitMsg := 'CRC error in data';
      155 : ExitMsg := 'Bad drive request structure length';
      156 : ExitMsg := 'Disk seek error';
      157 : ExitMsg := 'Unknown media type';
      158 : ExitMsg := 'Sector not found';
      159 : ExitMsg := 'Printer out of paper';
      160 : ExitMsg := 'Device write fault';
      161 : ExitMsg := 'Device read fault';
      162 : ExitMsg := 'Hardware failure';
      200 : ExitMsg := 'Division by zero';
      201 : ExitMsg := 'Range check error';
      202 : ExitMsg := 'Stack overflow';
      203 : ExitMsg := 'Heap overflow';
      204 : ExitMsg := 'Invalid pointer operation';
      205 : ExitMsg := 'Floating point overflow';
      206 : ExitMsg := 'Floating point underflow';
      207 : ExitMsg := 'Invalid floating point operation';
      216 : ExitMsg := 'General Protection fault'
      Else  ExitMsg := 'Unknown Error # ';
    End;
  If ExitMsg = '' Then
    Writeln('Normal Exit')
  Else Begin
    Textcolor(12);
    Writeln('Error occurred: ',ExitMsg);
  End;
End;
{$F-}

Procedure Init;
Begin
  TextColor(15);
  LinesRead     := 0;
  LinesWritten  := 0;
  LinesStripped := 0;
  If ParamStr(1) = '' Then Usage;
  ExitSave := ExitProc;
  ExitProc := @DeInit;    { install custom exit procedure }
End;

Procedure Open_Act_Log;
Begin
  Writeln('Testing Command Line...');
  Assign(TemplogDAT,'TEMPLOG.TMP');
  Rewrite(TemplogDAT);
  Assign(ActlogDAT,ParamStr(1));
  {$I-}
  Reset(ActlogDAT);
  {$I+}
  If IOResult <> 0 Then Begin
    TextColor(13);
    Writeln('Input file not found: ',ParamStr(1),'!!');
    Halt(2);
  End;
End;

Procedure Draw_BG;
Var
  X:Byte;
Begin
  ClrScr;
  TextColor(12);
  TextBackground(4);
  Write('');
  For X := 1 To 78 Do Write('');
  Write('');
  For X := 2 TO 21 Do Write('',' ':78,'');
  Write('');
  For X := 1 To 78 Do Write('');
  Write('');
  TextColor(15);
  GotoXY(27,1);  Write('[ Striplog REMOVER v',Ver,' ]');
  GotoXY(5,4);   Write('Options');
  GotoXY(40,4);  Write('Statistics');
  GotoXY(5,5);   For X := 1 to 27 Do Write('');
  GotoXY(40,5);  For X := 1 to 34 Do Write('');
  GotoXY(5,6);   Write('Remove the ANNOYING StripLog');
  GotoXY(5,7);   Write('comment at the end...');
  GotoXY(40,6);  Write('Number of Lines read:     0');
  GotoXY(40,8);  Write('Number of Lines written:  0');
  GotoXY(40,10); Write('Number of Lines stripped: 0');
  GotoXY(29,20); Write('***FREEWARE VERSION***');
  GotoXY(8,21);  Write('Copyright (C) 1994-1997 by Justin Pasher. All rights unknown...');
End;

Function Scan_Log:Boolean;
Var
  Line, Line2 : String;
  Found       : Boolean;
Begin
  Found := False;
  While Not Eof(ActlogDAT) and Not Found Do Begin
    GotoXY(66,6); Write(LinesRead);
    GotoXY(66,8); Write(LinesWritten);
    Inc(LinesRead);
    Readln(ActlogDAT,Line);
    { in case a faulty ACTIVITY log... }
    If Copy(Line,7,21) = 'Activity log stripped' Then Begin   { case 1 }
      Found := True;
      Inc(LinesStripped);
    End
    Else If Copy(Line,1,5)  = '-----' Then Begin              { case 2 }
      { If the line following the -'s contains 'Activity log stripped', then
        don't write the line with the -'s. This should only happen if Striplog
        is run two or more times in a row }
      If Not Eof(ActlogDAT) Then Begin
        { read into temp var, in case we need to save it }
        Inc(LinesRead);
        Readln(ActlogDAT,Line2);
        If Copy(Line2,7,21) = 'Activity log stripped' Then Begin
          Found := True;
          Inc(LinesStripped,2);
        End
        Else Begin
          Writeln(TemplogDAT,Line);     { otherwise, write the two lines }
          Writeln(TemplogDAT,Line2);
          Inc(LinesWritten,2);
        End;
      End;
    End
    Else Begin
      Inc(LinesWritten);
      Writeln(TemplogDAT,Line);                               { case 3 }
    End;
  End;
  Scan_Log := Found;
End;

Procedure Clean_Up;
Var
  BytesSaved : LongInt;
  Act,Temp   : File of Byte;
Begin
  Close(ActlogDAT);
  Close(TemplogDAT);        { *** New code to get 'Bytes Saved' *** }
  Assign(Act,ParamStr(1));
  Assign(Temp,'TEMPLOG.TMP');
  Reset(Act);
  Reset(Temp);
  BytesSaved := FileSize(Act)-FileSize(Temp);
  GotoXY(23,18);
  Writeln('Bytes Saved: ',BytesSaved);  { *** End new code (WOW!) *** }
  Erase(ActlogDAT);
  Rename(TemplogDAT,ParamStr(1));
  Assign(TemplogDAT,'TEMPLOG.TMP'); { so DeInit proc doesn't erase ACTIVITY log }
  TextBackground(0);
  GotoXY(1,23); Writeln('All done!');
  Done := True;
End;

Procedure Strip_Text;
Var
  Line          : String;
Begin
  Done := True;
  While Not Eof(ActlogDAT) and Done Do Begin
    Inc(LinesRead);
    Inc(LinesStripped);
    GotoXY(66,6);  Write(LinesRead);
    GotoXY(66,10); Write(LinesStripped);
    Readln(ActlogDAT,Line);
    { This checks for the end of the Striplog comment. If found and more
      exists after the comment, we need to go back to Scan_Log procedure }
    If (Copy(Line,1,5) = '-----') and Not Eof(ActlogDAT) Then Done := False;
  End;
  GotoXY(23,17); Write('Found an instance! Now removed...');
  If Done Then
    Clean_Up  { if no more scanning is needed, we clean up }
  Else
    ScanAgain := True;
End;

Procedure Not_Found;
Begin
  If Not ScanAgain Then Begin  { log only scanned once & no comment found }
    TextBackground(0);
    GotoXY(4,23);
    Writeln('No line found saying `Activity Log Stripped.'' Aborting...');
    Done := True;
  End
  Else Clean_Up;
End;

Begin
  Init;
  Open_Act_Log;
  Draw_BG;
  Repeat
    If Scan_Log Then Strip_Text Else Not_Found;
  Until Done;
End.